@@ -9,22 +9,20 @@ from ..json import DataJsonFormat, package_json_format
 @dataclasses_json.dataclass_json(letter_case=dataclasses_json.LetterCase.CAMEL)
 @dataclasses.dataclass
 class TransformColumn:
-    name: str
     transform: str
-    transformParams: typing.Any = dataclasses.field(default_factory=dict)
+    params: typing.Any = None
 
 
 @dataclasses_json.dataclass_json(letter_case=dataclasses_json.LetterCase.CAMEL)
 @dataclasses.dataclass
 class TransformTable:
-    id: str
-    columns: typing.List[TransformColumn]
+    columns: typing.Dict[str, TransformColumn]
 
 
 @dataclasses_json.dataclass_json(letter_case=dataclasses_json.LetterCase.CAMEL)
 @dataclasses.dataclass
 class Transform:
-    tables: typing.List[TransformTable]
+    tables: typing.Dict[str, TransformTable]
 
 
 TRANSFORM_JSON_FORMAT = package_json_format("slice_db.formats", "transform.json")
